==> openGion6.8.0.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE32S.sql <==
/****************************************************************************/
/* GE32 ( 送信履歴ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2017/01/05 15:18:51                                            */
/****************************************************************************/

CREATE TABLE GE32 (
   YKNO         INTEGER                 DEFAULT 0   NOT NULL            /*  10 要求NO   */
 , PARA_KEY     VARCHAR  (    9 )                                       /*  20 ﾊﾟﾗﾒｰﾀｷｰ */
 , PTN_ID       VARCHAR  (   20 )                                       /*  30 定型文ID */
 , SYSTEM_ID    VARCHAR  (   10 )                   NOT NULL            /*  40 ｼｽﾃﾑID   */
 , FROM_ADDR    VARCHAR  (  100 )                   NOT NULL            /*  50 送信元   */
 , TITLE        VARCHAR  (  300 )                                       /*  60 ﾀｲﾄﾙ     */
 , CONTENTS     VARCHAR  ( 4000 )                                       /*  70 内容     */
 , ATTACH1      VARCHAR  (  256 )                                       /*  80 添付1    */
 , ATTACH2      VARCHAR  (  256 )                                       /*  90 添付2    */
 , ATTACH3      VARCHAR  (  256 )                                       /* 100 添付3    */
 , ATTACH4      VARCHAR  (  256 )                                       /* 110 添付4    */
 , ATTACH5      VARCHAR  (  256 )                                       /* 120 添付5    */
 , UNIQ         IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR  (   14 )                                       /* 820 登録日時 */
 , PGSET        VARCHAR  (   10 )                                       /* 830 作成PG   */
 , PGPSET       VARCHAR  (   10 )                                       /* 840 作成親PG */
 , USRSET       VARCHAR  (   10 )                                       /* 850 作成社員 */
 , DYUPD        VARCHAR  (   14 )                                       /* 860 更新日時 */
 , PGUPD        VARCHAR  (   10 )                                       /* 870 更新PG   */
 , PGPUPD       VARCHAR  (   10 )                                       /* 880 更新親PG */
 , USRUPD       VARCHAR  (   10 )                                       /* 890 更新者   */
);

==> openGion7.2.8.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE32S.sql <==
/****************************************************************************/
/* GE32 ( 送信履歴ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:23                                            */
/****************************************************************************/

CREATE TABLE GE32 (
   YKNO         INTEGER                 DEFAULT 0   NOT NULL            /*  10 要求NO   */
 , PARA_KEY     VARCHAR  (    9 )                                       /*  20 ﾊﾟﾗﾒｰﾀｷｰ */
 , PTN_ID       VARCHAR  (   20 )                                       /*  30 定型文ID */
 , SYSTEM_ID    VARCHAR  (   10 )                   NOT NULL            /*  40 ｼｽﾃﾑID   */
 , FROM_ADDR    VARCHAR  (  100 )                   NOT NULL            /*  50 送信元   */
 , TITLE        VARCHAR  (  300 )                                       /*  60 ﾀｲﾄﾙ     */
 , CONTENTS     VARCHAR  ( 4000 )                                       /*  70 内容     */
 , ATTACH1      VARCHAR  (  256 )                                       /*  80 添付1    */
 , ATTACH2      VARCHAR  (  256 )                                       /*  90 添付2    */
 , ATTACH3      VARCHAR  (  256 )                                       /* 100 添付3    */
 , ATTACH4      VARCHAR  (  256 )                                       /* 110 添付4    */
 , ATTACH5      VARCHAR  (  256 )                                       /* 120 添付5    */
 , UNIQ         IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR  (   14 )                                       /* 820 登録日時 */
 , PGSET        VARCHAR  (   10 )                                       /* 830 作成PG   */
 , PGPSET       VARCHAR  (   10 )                                       /* 840 作成親PG */
 , USRSET       VARCHAR  (   10 )                                       /* 850 作成者   */
 , DYUPD        VARCHAR  (   14 )                                       /* 860 更新日時 */
 , PGUPD        VARCHAR  (   10 )                                       /* 870 更新PG   */
 , PGPUPD       VARCHAR  (   10 )                                       /* 880 更新親PG */
 , USRUPD       VARCHAR  (   10 )                                       /* 890 更新者   */
);
